<?php
$servername = "localhost";
$username = "wp_usertomp";
$password = "p3%Pz14YRM@";
$dbname = "tompedidos";



// Crear la conexión a MySQL
$conn = new mysqli($servername, $username, $password, $dbname);

// Verificar la conexión
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Seleccionar las coordenadas y la hora desde la base de datos, ordenado por timestamp
$sql = "SELECT latitude, longitude, timestamp,tipo FROM locations ORDER BY timestamp ASC";
$result = $conn->query($sql);

// Crear un array para almacenar las ubicaciones
$locations = [];
if ($result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $locations[] = $row;
    }
}
$conn->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Mapa de Rutas</title>
    <link rel="stylesheet" href="https://unpkg.com/leaflet@1.7.1/dist/leaflet.css" />
    <link rel="stylesheet" href="https://unpkg.com/leaflet-routing-machine@3.2.12/dist/leaflet-routing-machine.css" />
    <script src="https://unpkg.com/leaflet@1.7.1/dist/leaflet.js"></script>
    <script src="https://unpkg.com/leaflet-routing-machine@3.2.12/dist/leaflet-routing-machine.js"></script>
    <style>
        #map {
            height: 600px;
            width: 100%;
        }
    </style>
</head>
<body>

    <h1>Mapa de Rutas</h1>
    <div id="map"></div>

    <script>
        // Crear el mapa centrado en una ubicación predeterminada
        var map = L.map('map').setView([0, 0], 2);

        // Añadir el tile de OpenStreetMap
        L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
            maxZoom: 19,
            attribution: '© OpenStreetMap'
        }).addTo(map);

        // Array PHP que contiene las ubicaciones, ya ordenadas por timestamp
        var locations = <?php echo json_encode($locations); ?>;

        // Definir los iconos personalizados para el inicio (verde) y el final (rojo)
        var startIcon = L.icon({
            iconUrl: 'https://icons.iconarchive.com/icons/icons-land/vista-map-markers/48/Map-Marker-Push-Pin-1-Chartreuse-icon.png',  // Verde
            iconSize: [41, 41],
            iconAnchor: [20, 41],
            popupAnchor: [1, -34],
            shadowSize: [41, 41]
        });

        var endIcon = L.icon({
            iconUrl: 'https://icons.iconarchive.com/icons/icons-land/vista-map-markers/48/Map-Marker-Ball-Pink-icon.png',  // Rojo
            iconSize: [41, 41],
            iconAnchor: [20, 41],
            popupAnchor: [1, -34],
            shadowSize: [41, 41]
        });
		
		var pIcon = L.icon({
            iconUrl: 'https://icons.iconarchive.com/icons/gartoon-team/gartoon-misc/128/Gtk-Edit-icon.png',  // Rojo
            iconSize: [41, 41],
            iconAnchor: [20, 41],
            popupAnchor: [1, -34],
            shadowSize: [41, 41]
        });

        // Si hay más de un punto, creamos la ruta
        if (locations.length > 1) {
            // Convertir las ubicaciones en un formato que Leaflet Routing Machine pueda entender
            var waypoints = locations.map(function(location) {
                return L.latLng(parseFloat(location.latitude), parseFloat(location.longitude));
            });

            // Crear la ruta usando Leaflet Routing Machine y OSRM
            L.Routing.control({
                waypoints: waypoints,
                router: L.Routing.osrmv1({
                    serviceUrl: 'https://router.project-osrm.org/route/v1'
                }),
                createMarker: function(i, waypoint, n) {
                    // Obtener la fecha y hora del punto actual
                    var location = locations[i];
                    var timestamp = new Date(location.timestamp).toLocaleString();
					var tipo = location.tipo.toLocaleString();

                    // Personalizar el icono para el primer y último marcador
                    if (i === 0) {
                        return L.marker(waypoint.latLng, { icon: startIcon })
                            .bindPopup('Inicio<br>Latitud: ' + waypoint.latLng.lat + '<br>Longitud: ' + waypoint.latLng.lng + '<br>Fecha y Hora: ' + timestamp);
                    } else if (i === n - 1) {
                        return L.marker(waypoint.latLng, { icon: endIcon })
                            .bindPopup('Final<br>Latitud: ' + waypoint.latLng.lat + '<br>Longitud: ' + waypoint.latLng.lng + '<br>Fecha y Hora: ' + timestamp);
                    } else {
                        // Marcadores intermedios con el icono por defecto
						if(tipo === 'P') {
							return L.marker(waypoint.latLng, { icon: pIcon })
                            .bindPopup('Pedido<br>Latitud: ' + waypoint.latLng.lat + '<br>Longitud: ' + waypoint.latLng.lng + '<br>Fecha y Hora: ' + timestamp);
						} else {
                        	return L.marker(waypoint.latLng)
                            .bindPopup('Latitud: ' + waypoint.latLng.lat + '<br>Longitud: ' + waypoint.latLng.lng + '<br>Fecha y Hora: ' + timestamp);
							} 
                    }
                }
            }).addTo(map);

            // Centrar el mapa en la ruta
            map.fitBounds(L.latLngBounds(waypoints));
        }
    </script>

</body>
</html>



